/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common.metrics;

import org.apache.commons.lang3.StringUtils;

import org.apache.uniffle.common.config.RssBaseConf;
import org.apache.uniffle.common.config.RssConf;
import org.apache.uniffle.common.util.RssUtils;

public class MetricReporterFactory {

  public static MetricReporter getMetricReporter(RssConf conf, String instanceId) throws Exception {
    String name = conf.get(RssBaseConf.RSS_METRICS_REPORTER_CLASS);
    if (StringUtils.isEmpty(name)) {
      return null;
    }

    return (AbstractMetricReporter)
        RssUtils.getConstructor(name, RssConf.class, String.class).newInstance(conf, instanceId);
  }
}
